{% extends "admin/base_site.html" %}
{% load i18n %}

{% block breadcrumbs %}
<div class="breadcrumbs">
<a href="{% url 'admin:index' %}">{% translate 'Home' %}</a>
&rsaquo; {% translate 'Password reset' %}
</div>
{% endblock %}

{% block content %}

<p>{% translate "Your password has been set.  You may go ahead and log in now." %}</p>

<p><a href="{{ login_url }}">{% translate 'Log in' %}</a></p>

{% endblock %}
